@@ -26,6 +26,7 @@ import argparse
 import logging
 import sys
 import os
+import multiprocessing as mp
 
 from disdat import apply
 from disdat import dockerize
@@ -36,7 +37,6 @@ from disdat.lineage import init_lineage_cl
 from disdat.common import DisdatConfig, load_class
 from disdat import log
 
-
 _pipes_fs = None
 
 DISDAT_PATH = os.environ.get("PATH", None)
@@ -45,11 +45,14 @@ DISDAT_PYTHONPATH = os.environ.get("PYTHONPATH", None)
 
 def main():
     """
-    Main as a function for testing convenience and as a package entry point.
-
-    :return: (shape of input df, shape of pushed df)
+    Main is the package entry point.
     """
 
+    # MacOS X fails when we multi-process using fork and boto sessions.
+    # One fix is to set export OBJC_DISABLE_INITIALIZE_FORK_SAFETY=YES
+    # But only in the shell.  To avoid this, we only mp with the forkserver.
+    mp.set_start_method('forkserver')
+
     if getattr(sys, 'frozen', False):
         here = os.path.join(sys._MEIPASS, 'disdat')
     else:
